<?php 
// Export Host Service Tool COMPONENT
//
//include the helper file
require_once(dirname(__FILE__).'/../componenthelper.inc.php');

// respect the name
$exporthostservicetool_component_name="exporthostservicetool";

// run the initialization function
exporthostservicetool_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function exporthostservicetool_component_init(){
	global $exporthostservicetool_component_name;
	
	//boolean to check for latest version
	$versionok=exporthostservicetool_component_checkversion();
	
	//component description
	$desc="The purpose of this Tool is to give you the ability to view and export a list of Hosts and Services running on your Nagios XI host.";
	
	if(!$versionok)
		$desc="<b>Error: This component requires Nagios XI 2009R1.2B or later.</b>";
	
	//all components require a few arguments to be initialized correctly.  
	$args=array(
		COMPONENT_NAME => $exporthostservicetool_component_name,
		COMPONENT_VERSION => '1.0.3', 
		COMPONENT_DATE => '10-29-2020',
		COMPONENT_AUTHOR => "Nagios Enterprises",
		COMPONENT_DESCRIPTION => $desc,
		COMPONENT_TITLE => "Export Host Service Tool",
		);
	
	//register this component with XI 
	register_component($exporthostservicetool_component_name,$args);
	
	// register the addmenu function
	if($versionok)
		register_callback(CALLBACK_MENUS_INITIALIZED,'exporthostservicetool_component_addmenu');
	
	} /* End function exporthostservicetool_component_init(){ */
	


////////////////////////////////////////////////////////////////////////
// CONFIG FUNCTIONS
////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function exporthostservicetool_component_checkversion(){

	if(!function_exists('get_product_release'))
		return false;
	//requires greater than 2009R1.2
	if(get_product_release()<114)
		return false;

	return true;
	}
	
function exporthostservicetool_component_addmenu($arg=null){
	global $exporthostservicetool_component_name;
	//retrieve the URL for this component
	$urlbase=get_component_url_base($exporthostservicetool_component_name);
	
	$menu_check = find_menu_item(MENU_TOOLS,"menu-tools-section-tools","id");

	if ($menu_check == false) {
		add_menu_item(MENU_TOOLS,array(
			"type" => "menusection",
			"title" => gettext("Export Host Service Tool"),
			"id" => "menu-tools-section-tools",
			"order" => 10100,
			"opts" => array(
				"id" => "tools",
				"expanded" => true,
				)
			));
		} /* End if ($menu_check == false) { */

	add_menu_item(MENU_TOOLS,array(
		"type" => "link",
		"title" => "Export Host and Services",
		"id" => "menu-tools-section-exporthostservice",
		"order" => 10200,
		"opts" => array(
			//this is the page the menu will actually point to.
			//all of my actual component workings will happen on this script
			"href" => $urlbase."/exporthostservicetool.php",      
			)
		));

		if ($menu_check == false) {
			add_menu_item(MENU_TOOLS,array(
				"type" => "menusectionend",
				"id" => "menu-tools-sectionend-tools",
				"order" => 11000,
				"title" => "",
				"opts" => ""
				));
			} /* End if ($menu_check == false) { */
				
	} /* End function exporthostservice_component_addmenu($arg=null){ */


?>
