<?php
//
// Copyright (c) 2008-2020 Nagios Enterprises, LLC. All rights reserved.
//

require_once(dirname(__FILE__) . '/../componenthelper.inc.php');

// Initialization stuff
pre_init();
init_session();

// Grab GET or POST variables and check pre-reqs
grab_request_vars();
check_prereqs();
check_authentication();

// Only admins can access this page
if (is_admin() == false) {
    $content .= _("You are not authorized to access this feature.  Contact your Nagios XI administrator for more information, or to obtain access to this feature.");
    exit();
}

route_request();

function route_request()
{
    $cmd = grab_request_var('cmd', '');

    switch ($cmd)
    {
        case 'show':
            show_profile(false);
            break;

        case 'download':
            show_profile(true);
            break;

        default:
            show_page();
            break;
    }
}

function show_page()
{
    do_page_start(array("page_title" => _("Host - Service Export Tool")), true);
?>

<script type="text/javascript">
$(document).ready(function() {

    $('#show-profile').click(function() {
        whiteout();
        show_throbber();
        $.get('', { cmd: 'show' }, function(data) {
            hide_throbber();
            clear_whiteout();
            $('#profile').html(data);
        });
    });

});
</script>

<h1><?php echo _('Host - Service Export Tool'); ?></h1>
<p><?php echo _('The purpose of the Export Hosts and Services Tool is to Export a TSV (Tab Separated Values) list of Hosts and Services from the running configuration.'); ?></p>
<p><?php echo _('It will export the file to the /usr/local/nagiosxi/tmp/ folder on the Nagios Server and optionally, you can Download a ZIP copy of the file by clicking on the Download button.'); ?></p>
<div style="margin-bottom: 20px;">
    <button type="button" id="show-profile" class="btn btn-sm btn-primary"><?php echo _('Export'); ?></button>
    <a href="?cmd=download" class="btn btn-sm btn-default"><i class="fa fa-download"></i> <?php echo _('Download'); ?></a>
</div>

<div id="profile"></div>

<?php
    do_page_end(true);
}

function show_profile($download = false)
{
    if ($download) {
        get_logs_and_snapshot();
    } else {
        $content = build_profile_output($download);
        echo nl2br($content);
    }
}


function build_profile_output($download)
{
	global $cfg;
	exec('/bin/echo -e "nagios_hosts.host_object_id\\tnagios_services.host_object_id\\tnagios_hosts.alias\\tnagios_hosts.address\\tnagios_services.display_name\\tnagios_service.nagios_commands.command_line\\tnagios_services.check_command_args\\tnagios_service_contacts.service_id\\tnagios_contacts.contact_object_id\\tnagios_contacts.alias\\tnagios_host.host_id\\tnagios_contactgroup.contactgroup_object_id\\tnagios_contactgroup.contactgroup_object_id\\tnagios_contactgroup.alias\\tnagios_contactgroup.email_address\\tnagios_host.host_id" >/usr/local/nagiosxi/tmp/hostservice.tsv');

	$server = grab_array_var($cfg['db_info']['ndoutils'],'dbserver');
	$user = grab_array_var($cfg['db_info']['ndoutils'],'user');
	$password = grab_array_var($cfg['db_info']['ndoutils'],'pwd');
	$db = grab_array_var($cfg['db_info']['ndoutils'],'db');
// 10-15-2020 Added showing contactgroups for hosts.
	exec('/usr/bin/mysql -u ' .$user. ' -p'.$password.' -h '.$server.' --database '.$db.' -e \'select nagios.nagios_hosts.host_object_id,nagios.nagios_services.host_object_id,nagios.nagios_hosts.alias,nagios.nagios_hosts.address,nagios.nagios_services.display_name,nagios.nagios_commands.command_line,nagios.nagios_services.check_command_args,nagios.nagios_service_contacts.service_id,nagios.nagios_contacts.contact_object_id,nagios.nagios_contacts.alias,nagios.nagios_contacts.email_address,nagios.nagios_host_contactgroups.host_id,nagios.nagios_host_contactgroups.contactgroup_object_id,nagios.nagios_contactgroups.contactgroup_object_id,nagios_contactgroups.alias,nagios.nagios_hosts.host_id from nagios_hosts inner join nagios.nagios_services on nagios.nagios_hosts.host_object_id = nagios.nagios_services.host_object_id left join nagios.nagios_commands on nagios.nagios_services.check_command_object_id = nagios.nagios_commands.object_id right join nagios.nagios_service_contacts on nagios.nagios_services.service_id = nagios.nagios_service_contacts.service_id left join nagios.nagios_contacts on nagios.nagios_contacts.contact_object_id = nagios.nagios_service_contacts.contact_object_id left JOIN nagios.nagios_host_contactgroups ON nagios.nagios_hosts.host_id = nagios.nagios_host_contactgroups.host_id left JOIN nagios.nagios_contactgroups ON nagios.nagios_host_contactgroups.contactgroup_object_id =  nagios.nagios_contactgroups.contactgroup_object_id;\' -B >>/usr/local/nagiosxi/tmp/hostservice.tsv');

	$tsv = "/usr/local/nagiosxi/tmp/hostservice.tsv";
	//addcommaquotes( $tsv );
}



function get_logs_and_snapshot()
{
	// Add the creaton of the CSV file here incase the user doesn't use the export button
	build_profile_output($download);

    //zip Files
    exec('/usr/bin/zip  /usr/local/nagiosxi/tmp/hostservice.zip /usr/local/nagiosxi/tmp/hostservice.tsv');

    // zip was packaged, send it to user
    $zip = "/usr/local/nagiosxi/tmp/hostservice.zip";

    //more checks
    if (!file_exists($zip)) {
        echo "Failed to retrieve zip file!\n";
        exit();
    }

    $mime_type = "application/zip";
    header('Content-type: ' . $mime_type);
    header("Content-length: " . filesize($zip));
    header('Content-Disposition: attachment; filename="' . basename($zip) . '"');
    $f = file_get_contents($zip, 'rb');
    //print binary output to browser
    echo $f;

    //remove zip
    unlink($zip);
}

function addcommaquotes($filename)
{
	// replaces tab with ","
	exec( 'sed -i "s/\t/\",\"/g" '. $filename .'' );
	// adds " to the begining of the line
	exec( 'sed -i -e "s/^/\"/" '. $filename .'' );
	// adds " to the end of the line
	exec( 'sed -i -e "s/$/\"/" '. $filename .'' );
}
